pub struct AsyncPerform<C, A>{ /* private fields */ }Expand description
The AsyncPerform struct is the result when calling nonblocking() function to signify the end of the builder. The main job of this is to perform the Curl in nonblocking fashion.
Implementations
Sourceimpl<C, A> AsyncPerform<C, A>
impl<C, A> AsyncPerform<C, A>
Sourcepub async fn send_request(self) -> Result<Easy2<C>, Error<C>>
pub async fn send_request(self) -> Result<Easy2<C>, Error<C>>
This will send the request asynchronously,
and return the underlying Easy2<C> useful if you
want to decide how to transform the response yourself.
This becomes a non-blocking I/O since the actual perform operation is done at the actor side using Curl-Multi perform.
Sourcepub async fn send_request_easy2(self) -> Result<Easy2<C>, Error<C>>
pub async fn send_request_easy2(self) -> Result<Easy2<C>, Error<C>>
This will send the request asynchronously,
and return the underlying Easy2<C> useful if you
want to decide how to transform the response yourself.
This becomes a non-blocking I/O since the actual perform operation is done at the actor side using Curl Easy2 perform.